Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3721)

Unified Diff: chrome/browser/ui/webui/md_history_ui.h

Issue 2318643003: MD History: truncate title to 300 chars in C++ instead of JS (Closed)
Patch Set: more !android Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/ui/webui/log_web_ui_url_browsertest.cc ('k') | chrome/browser/ui/webui/md_history_ui.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/webui/md_history_ui.h
diff --git a/chrome/browser/ui/webui/md_history_ui.h b/chrome/browser/ui/webui/md_history_ui.h
index 117aff21c230464c2c3cb612240e631a0c3feead..2d025de2698b28aec0bf3428fea3ff5db1c8b0b5 100644
--- a/chrome/browser/ui/webui/md_history_ui.h
+++ b/chrome/browser/ui/webui/md_history_ui.h
@@ -21,8 +21,9 @@ class MdHistoryUI : public content::WebUIController {
~MdHistoryUI() override;
static bool IsEnabled(Profile* profile);
- // Reset the current list of features and explicitly disable MD History.
- static void DisableForTesting();
+
+ // Reset the current list of features and explicitly set MD History enabled.
+ static void SetEnabledForTesting(bool enabled);
static base::RefCountedMemory* GetFaviconResourceBytes(
ui::ScaleFactor scale_factor);
« no previous file with comments | « chrome/browser/ui/webui/log_web_ui_url_browsertest.cc ('k') | chrome/browser/ui/webui/md_history_ui.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698